@@ -139,9 +139,6 @@ class Aliyun:
         request.set_SecurityGroupId(self.get_config('security_group_id'))
         request.set_KeyPairName(self.get_config('key_pair_name'))
         request.set_RamRoleName(self.get_config('ram_role_name'))
-        request.set_SpotPriceLimit(self.get_config('spot_price_limit'))
-        request.set_CreditSpecification(self.get_config('credit_specification'))
-
 
 
         tags = [{"Key": "source", "Value": self.context.get_root_config("tag", "ttlecs")}]
